@@ -22,8 +22,9 @@ import logging
 from gi.repository import Gio
 
 from nbxmpp.const import TCPState
-from nbxmpp.util import Observable
 from nbxmpp.util import LogAdapter
+from nbxmpp.util import min_version
+from nbxmpp.util import Observable
 
 log = logging.getLogger('nbxmpp.connection')
 
@@ -59,6 +60,7 @@ class Connection(Observable):
         self._state = None
 
         self._state = TCPState.DISCONNECTED
+        self._tls_con: Optional[Gio.TlsConnection] = None
 
         self._peer_certificate = None
         self._peer_certificate_errors = None
@@ -68,17 +70,39 @@ class Connection(Observable):
 
     @property
     def tls_version(self) -> Optional[int]:
-        return None
+        if self._tls_con is None:
+            return None
+
+        if not min_version('GLib', '2.69.0'):
+            return None
+
+        return self._tls_con.get_protocol_version()
 
     @property
-    def ciphersuite(self) -> Optional[int]:
-        return None
+    def ciphersuite(self) -> Optional[str]:
+        if self._tls_con is None:
+            return None
+
+        if not min_version('GLib', '2.69.0'):
+            return None
+
+        return self._tls_con.get_ciphersuite_name()
 
     def get_channel_binding_data(
         self,
-        type_: Gio.TlsChannelBindingType  # pylint: disable=unused-argument
+        type_: Gio.TlsChannelBindingType
     ) -> Optional[bytes]:
-        return None
+        assert self._tls_con is not None
+
+        try:
+            success, data = self._tls_con.get_channel_binding_data(type_)
+        except Exception as error:
+            self._log.warning('Unable to get channel binding data: %s', error)
+            return None
+
+        if not success:
+            return None
+        return data
 
     @property
     def local_address(self):
@@ -160,3 +184,4 @@ class Connection(Observable):
         self._peer_certificate = None
         self._client_cert = None
         self._address = None
+        self._tls_con = None
