@@ -17,18 +17,16 @@
 
 import logging
 from collections import deque
-from typing import Optional
 
-from gi.repository import GLib
 from gi.repository import Gio
+from gi.repository import GLib
 from gi.repository import GObject
 
-from nbxmpp.const import TCPState
-from nbxmpp.const import ConnectionType
-from nbxmpp.util import utf8_decode
-from nbxmpp.util import convert_tls_error_flags
-from nbxmpp.util import min_version
 from nbxmpp.connection import Connection
+from nbxmpp.const import ConnectionType
+from nbxmpp.const import TCPState
+from nbxmpp.util import convert_tls_error_flags
+from nbxmpp.util import utf8_decode
 
 log = logging.getLogger('nbxmpp.tcp')
 
@@ -64,47 +62,6 @@ class TCPConnection(Connection):
 
         self._keepalive_id = None
 
-    @property
-    def tls_version(self) -> Optional[int]:
-        if self._con is None:
-            return None
-
-        if not min_version('GLib', '2.69.0'):
-            return None
-
-        tls_con = self._con.get_base_io_stream()
-        return tls_con.get_protocol_version()
-
-    @property
-    def ciphersuite(self) -> Optional[str]:
-        if self._con is None:
-            return None
-
-        if not min_version('GLib', '2.69.0'):
-            return None
-
-        tls_con = self._con.get_base_io_stream()
-        return tls_con.get_ciphersuite_name()
-
-    def get_channel_binding_data(
-        self,
-        type_: Gio.TlsChannelBindingType
-    ) -> Optional[bytes]:
-        if self._con is None:
-            return None
-
-        tls_con = self._con.get_base_io_stream()
-
-        try:
-            success, data = tls_con.get_channel_binding_data(type_)
-        except Exception as error:
-            self._log.warning('Unable to get channel binding data: %s', error)
-            return None
-
-        if not success:
-            return None
-        return data
-
     def connect(self):
         self.state = TCPState.CONNECTING
 
@@ -207,7 +164,7 @@ class TCPConnection(Connection):
         self._log.info('Send keepalive')
         self._keepalive_id = None
         if not self._con.get_output_stream().has_pending():
-            self._write_all_async(' '.encode())
+            self._write_all_async(b' ')
 
     def start_tls_negotiation(self):
         self._log.info('Start TLS negotiation')
@@ -216,16 +173,16 @@ class TCPConnection(Connection):
         identity = Gio.NetworkAddress.new(self._address.domain,
                                           remote_address.props.port)
 
-        tls_client = Gio.TlsClientConnection.new(self._con, identity)
+        self._tls_con = Gio.TlsClientConnection.new(self._con, identity)
 
         if self._address.type == ConnectionType.DIRECT_TLS:
-            tls_client.set_advertised_protocols(['xmpp-client'])
-        tls_client.connect('accept-certificate', self._check_certificate)
-        tls_client.connect('notify::peer-certificate', self._on_certificate_set)
+            self._tls_con.set_advertised_protocols(['xmpp-client'])
+        self._tls_con.connect('accept-certificate', self._check_certificate)
+        self._tls_con.connect('notify::peer-certificate', self._on_certificate_set)
 
         # This Wraps the Gio.TlsClientConnection and the Gio.Socket together
         # so we get back a Gio.SocketConnection
-        self._con = Gio.TcpWrapperConnection.new(tls_client,
+        self._con = Gio.TcpWrapperConnection.new(self._tls_con,
                                                  self._con.get_socket())
 
     def _read_async(self):
